/* ************************************************************************** */
/** Descriptive File Name
  @ Author
    Richard Wall
 
  @ Date
    Created:    May 28, 2016
    Revised:    March 29, 2017  
    Verified:   May 16, 2017

  @Company
    Digilent Inc.      

  @File Name
    calc.h

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @Summary
    Simple calculator key definitions and operations.

  @Description
    Defines switches SW0 through SW3 as nibble A and SW4 through SW7 as nibble
    B, Defines BTND, BTNC, BTNR, BTNU, and BTNL as ADD, SUB, MUlT, DIV, 
    and CLEAR.
 */
/* ************************************************************************** */

#ifndef _CALC_H_   /* Guard against multiple inclusion */
#define _CALC_H_

// *****************************************************************************
// *****************************************************************************
// Section: Interface Functions
// *****************************************************************************
// *****************************************************************************

// *****************************************************************************
/**
    @Function
        int get_xy(int *x, int *y); 
    @Summary
        Brief one-line description of the function.
    @Description
        * Translates the SWITCH inputs SW0 through SW3 as value x and SW4 
        * through SW7 as value y.
        * Data enter to the calculator uses hexadecimal format
    @Precondition
        * LED IO pins have been initialized as outputs
    @Parameters
        @param param1: pointer to x in range of 0b0000 to 0b1111 ( 0 - 15d )
        @param param2: pointer to y in range of 0b0000 to 0b1111 ( 0 - 15d )
    @Returns
        * List (if feasible) and describe the return values of the function.
        * 1   Indicates an error occurred
        * 0   Indicates an error did not occur
    @Remarks
        * Returned error flag indicates the value of either x or y is out of
        * range 0 through 15.
    @Example
        @code
             error_flag =  get_xy(int *x, int *y); 
     */
     
    int get_xy(int *x, int *y);  

#endif /* _CALC_H_ */

/* *****************************************************************************
 End of File calc.h
 */
