/**********************  Lab 4a **********************************************
 *
 * File:        Project Lab4a.c
 * Author:      Richard Wall
 * Date:        October 26, 2016
 * Rev.         February 4, 2014
 *              December 15, 2015 - MPLAB X v2.26 - XC32 v1.34
 * Verified:    May 16, 2017 -  MPLAB X v3.61 - XC32 v1.43
 *
 * Notes:       This project demonstrates the methods to configure a serial 
 *              port and implement bidirectional serial communications. The 
 *              serial port is initialized for 19200 BAUD with ODD parity. 
 *              Communications from the computer terminal is displayed on the
 *              Basys MX3 LCD. Changing the toggle switch settings on the 
 *              Basys MX3 cause a report to be generated containing the status
 *              of the slide switches and sends a text message to the computer
 *              terminal.
 * 
 *              BTND must be pressed to clear the sign-on message and run the
 *              application program.
 *  @Development Environment
 *  MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
 *  XC32 1.43 - http://www.microchip.com/mplab/compilers
 *  PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
 * 
 * ****   This application uses a peripheral bus clock set to 10MHz.  ****
 *   PBCLK set for 10 MHz, Set parameters in config_bits.h and hardware.h
 *
 **************************************************************************** */

/* Included files for platform */
#include "hardware.h"
#include "config_bits.h"
#include "swDelay.h"

/* Included files for system */
#include <plib.h>
#include <stdio.h>

/* Included files for application */
#include "LCDlib.h"
#include "comm_lib.h" 

int main(void)
{
char uartPutStr[40];
char uartGetStr[40];
int  uartGetStrLen = 40;
int  uartGetStrRdy = 0;
unsigned int sw1, sw2 = 0;

    Hardware_Setup();
    uart4_init(19200, ODD_PARITY);
    initLCD();
    clrLCD();               // Display sign-on message
    putsLCD( "Digilent");
    gotoLCD(16);            // Position cursor to second line
    putsLCD( "Basys MX3 Lab 4a");
    printf("Press BTND to continue\n\r");
    while(!BNTD());         // Wait for button press to continue
    while(1)
    {
        uartGetStrRdy = getstrU4( uartGetStr, uartGetStrLen );
        if(uartGetStrRdy != 0)
        {
            clrLCD();
            putsLCD(uartGetStr);
        }
        sw1 = Switch2Binary();
        if(sw1 != sw2)
        {
            sw2 = sw1;
            sprintf(uartPutStr,"%d %d %d %d %d %d %d %d ",
            (sw1>>7 & 0x01), (sw1>>6 & 0x01), (sw1>>5 & 0x01), (sw1>>4 & 0x01),
            (sw1>>3 & 0x01), (sw1>>2 & 0x01), (sw1>>1 & 0x01), (sw1>>0 & 0x01));
            printf("%s 0X%X %uD \r\n", uartPutStr, sw1, sw1);
            printf("Digilent Basys MX3\n\r");
        }
    }
    return EXIT_FAILURE;
}

// End of Lab4a.c
