/**********************  Lab 4b **********************************************
 *
 * File:        Project Lab4b.c
 * Author:      Richard Wall
 * Date:        October 28, 2016
 * Rev.         February 4, 2014
 *              December 15, 2015 - MPLAB X v2.26 - XC32 v1.34
 * Verified:    May 16, 2017 -  MPLAB X v3.61 - XC32 v1.43
 *
 * Notes:       This project demonstrates the methods to configure a serial 
 *              port and implement bidirectional serial communications. The 
 *              serial port is initialized for 19200 BAUD with ODD parity. 
 *              Communications from the computer terminal is displayed on the
 *              Basys MX3 LCD. Changing the toggle switch settings on the 
 *              Basys MX3 cause a report to be generated containing the status
 *              of the slide switches and sends a text message to the computer
 *              terminal.
 * 
 *              BTND must be pressed to clear the sign-on message and run the
 *              application program.
 * 
 **************************************************************************** */

/* Included files for platform */
#include "hardware.h"
#include "config_bits.h"
#include "swDelay.h"

/* Included files for system */
#include <plib.h>
#include <stdio.h>
#include <string.h>

/* Included files for application */
#include "lab4b.h"
#include "LCDlib.h"
#include "comm_lib.h"
#include "push_on_off.h"
#include "stepper.h"

static void decode(char *str, int rpm);

extern int step_delay;          // Default initial value
extern int step_dir;            // Default initial value
extern int step_mode;           // Default initial value

extern unsigned int pbTrig;     // push button change notice (ISR))

int main(void)
{
char uartPutStr[40];
char uartGetStr[40];
int  uartGetStrLen = 40;
int  uartGetStrRdy = 0;
int  ctrl = 1;  // local control
int rpm, s_rpm = 0, s_dir = 1, s_mode = 1;
int cmd_error;
int len, i;
char dirStr[6];
char modeStr[6];
char rpmStr[6];

    Hardware_Setup();
    uart4_init(19200, ODD_PARITY);
    initLCD();
    stepper_init();
    push_on_offInit();
    while(1)
    {
        if(pbTrig) 
        {
            push_on_off(); // Call button toggle only when button changes 
        }
        if(PORTA & (LED1_bit))
        {
            if(ctrl == 0)
            {
                printf("System is under remote control\n\r");
                ctrl = 1;
            }
            uartGetStrRdy = getstrU4( uartGetStr, uartGetStrLen );
			// If data is available in the Uart4 buffer, read it and see
			// if it matches any predefined commands
            if(uartGetStrRdy != 0)
            {   cmd_error = 0;
                sscanf(uartGetStr,"%s %s %s", dirStr, modeStr, rpmStr);
                if((strcmp(modeStr, "FULL") && strcmp(modeStr, "FULL")))
                {
                    cmd_error |= 1;
                }
                else
                {
                    if(!strcmp(modeStr, "FULL"))
                        step_mode = SM_FULL_STEP;
                    else
                        step_mode = SM_HALF_STEP;
                }
                
                if((strcmp(dirStr, "CW") && strcmp(dirStr, "CCW")) || cmd_error)
                {
                    cmd_error |= 1;
                }
                else
                {
                    if(!strcmp(dirStr, "CW"))
                        step_dir = SM_CW;
                    else
                        step_dir = SM_CCW;
                }
                if(!cmd_error)
                {
                    len = strlen(rpmStr);
                    for(i=0; i<len; i++)
                    {
                        if((rpmStr[i]<'0') || (rpmStr[i]>'9'))
                        {
                            cmd_error |= 1;
                        }
                        if(!cmd_error)
                        {
                            rpm = atoi(rpmStr);
                            clrLCD();
                            putsLCD(uartGetStr);
                        }
                    }
                }
                else
                {
                    printf("\n\rCommand text error\n\r");
                }
            }
        }
		// If there is no data in the UART4 buffer, control the motor
        else
        {
            if(ctrl == 1)
            {
                printf("System is under local control\n\r");
                ctrl = 0;
            }
            rpm = Switch2Binary();  // Poll switches to determine set speed
            if(rpm == 0)            // Avoid divide by zero
            {
                step_delay = RPM2MSPERHALFSTEP;
            }
            else
            {
                step_mode = ((int)(PORTA & (LED0_bit)) + 1);
                if(PORTA & (LED2_bit))
                {
                    step_dir = 1;
                }
                else
                {
                    step_dir = -1;
                }
                step_delay = (int) ((RPM2MSPERHALFSTEP * step_mode) / ( rpm ));
                if((step_dir != s_dir) || (step_mode != s_mode) || rpm != s_rpm)
                {
                    s_dir = step_dir;
                    s_mode = step_mode;
                    s_rpm = rpm;
                    if(s_dir == -1)
                        strcpy(dirStr,"CCW");
                    else
                        strcpy(dirStr,"CW ");
                    if(s_mode == 1)
                        strcpy(modeStr,"HALF");
                    else
                        strcpy(modeStr,"FULL");
                    sprintf(uartPutStr,"%s %s %d", dirStr, modeStr, rpm);
                    clrLCD();
                    putsLCD(uartPutStr);
                    printf("%s\n\r", uartPutStr);
                }
            }
        }
    }
    return 0;
}

static void decode(char *str, int rpm)
{
    
}

// End of Lab4a.c
