/* ************************************************************************** */
/** Descriptive File Name: Lab6.c - main project for Unit 6 contains code for 
 * both Lab 6a and  Lab 6b buy switching SW0. When SW0 is switched off, the open
 * loop control is active. When SW0 is switch on the closed loop control is 
 * active.

  @ Author
    Richard Wall
 
  @Date
    Created:    August 17, 2016
    Revised:    March 2, 2017 - Implements both Lab 6a and 6b using SW0 control
    Verified:   May 20, 2017

  @Company
    Digilent Inc.

  @File Name
   lab6.c

  @Summary
    DC Motor speed control.

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @Description
    Provides both open or closed loop DC motor speed control

  @Remarks
    Uses C32 peripheral library. See 
 http://ww1.microchip.com/downloads/en/DeviceDoc/32bitPeripheralLibraryGuide.pdf
 http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
  
    External 5VDC supply required for motor supply

****   This application uses a peripheral bus clock set to 10MHz.  ****
    PBCLK set for 10 MHz, Set parameters in config_bits.h and hardware.h

  ************************************************************************** */

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

/* Included files for system */
#include "hardware.h"
#include "config_bits.h"
#include <plib.h>
#include <stdio.h>

// Include common platform header files
#include "LCDlib.h"
#include "comm_lib.h"
#include "swDelay.h"

// Include application header files
#include "lab6.h"
#include "motor.h"

extern float rps;           // Measured speed
extern int set_speed;       // Reference speed
extern int cn;              // Control voltage
extern int en;              // Control error
extern int adc2;            // Pot ADC value

int main(void)
{
char lcdStr1[20];

    Hardware_Setup();
//  Set_All_Switches_Input(); 
    initLCD();
    uart4_init(38400, NO_PARITY);

    motor_init();
	// while running continually update the screen with the current
	// speed and rpm
    while(1)
    {
        invLED1();
        clrLCD(); 
        sprintf(lcdStr1,"spd:%3d rps:%3d", set_speed, (int) rps);   
        putsLCD(lcdStr1);
        setLCDC(0x40);	// Set to second line of LCD
        sprintf(lcdStr1,"cn:%4d en:%4d", cn, en);   // Convert integer to string
        putsLCD(lcdStr1);
        printf("ADC: %4d Speed: %4d RPS: %4d PWM:%5d ERROR: %4d\n\r", 
                adc2, set_speed, (int) rps, cn, en);
        msDelay(250);
    } 
    return (EXIT_FAILURE);      // Should never reach this statement
}
// End of Lab6.c
