/* ************************************************************************** */
/** Descriptive File Name:   micInput.h for Lab 7b

  @ Author
    Richard Wall
 
  @ Date
    @ Created;    
        April 30, 2016, 9:58 AM
    @ Modified:  
        February 19, 2017        
    @ Verified:
        May 19, 2017

  @Company
    Digilent Inc

  @Development Environment
    MPLAB X IDE x3.61 - http://www.microchip.com/mplab/mplab-x-ide 
	XC32 1.43 - http://www.microchip.com/mplab/compilers
	PLIB 3/7/20162 - http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library

  @File Name
    micInput.h

  @Summary
    Reads the microphone analog input

  @Description

  @Remarks
    Uses XC32 peripheral library. See 
 http://ww1.microchip.com/downloads/en/DeviceDoc/32bitPeripheralLibraryGuide.pdf
 http://www.microchip.com/SWLibraryWeb/product.aspx?product=PIC32%20Peripheral%20Library
 */
/* ************************************************************************** */

/* ************************************************************************** */
/** Descriptive File Name

  @Company
    Digilent Inc

  @File Name
    micInput.h

  @Summary
    Reads the microphone analog input

  @Description
    Describe the purpose of this file.
 */
/* ************************************************************************** */

#ifndef _ANALOGINPUT_H_    /* Guard against multiple inclusion */
    #define _ANALOGINPUT_H_


/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Included Files                                                    */
/* ************************************************************************** */
/* ************************************************************************** */

#include "hardware.h"
#include <plib.h>

/* ************************************************************************** */
/* ************************************************************************** */
/* Section: Constants                                                         */
/* ************************************************************************** */
/* ************************************************************************** */

/* ************************************************************************** */
/** Descriptive Constant Name
  @Summary
     ADC sample rate - samples per second   
***************************************************************************** */

    #define FS                  16000   // 16KHz sample rate

/* ADC sample period. Over sampling can be used if needed but the sample rate
 * must be scaled. */
    #define OVER_SAMPLE_RATE    1       // Sample rate divider (over sampling)       
    #define SAMPLE_INTERVAL     GetPeripheralClock() / ( FS * OVER_SAMPLE_RATE )

#endif /* _ANALOGINPUT_H_ */

/* ***************************************************************************
      @Function
        int void initiate_ADC(void); 

      @Summary
        Initializes the microphone ADC to be initiated by the the Timer 3 
        interrupt

      @Description
        Full description, explaining the purpose and usage of the function.
        <p>
        Additional description in consecutive paragraphs separated by HTML 
        paragraph breaks, as necessary.
        <p>

    @Precondition
        None.

    @Parameters
        None

    @Returns
        None

    @Example
      @code
        void initiate_ADC(void)
        {
             ...           
        }
*/
void initiate_ADC(void);

/* ***************************************************************************
      @Function
        unsigned int Read_ADC(int channel); 

      @Summary
        Reads the specified channel buffer.

      @Description
        Waits for the next conversion to be completed before reading.
        <p>
        This assumes that auto sampling is enabled so a new sample period 
        starts as soon as the conversion is completed.

    @Precondition
        AD converter has been initialized

    @Parameters
        Channel - indicates which ADC buffer to read.

    @Returns
      signed integer in the range of 0 to 1023

    @Example
      @code
      unsigned int Read_ADC(int channel)
      {
        int adc;
         ...           
        return adc;
      }
*/
unsigned int Read_ADC(int channel); 

/* *****************************************************************************
 End of micInput.h
 */
